# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('mfa', '0004_user_keys_enabled'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user_keys',
            name='secret_key',
        ),
        migrations.AddField(
            model_name='user_keys',
            name='properties',
            field=jsonfield.fields.JSONField(null=True),
        ),
        migrations.RunSQL("alter table mfa_user_keys modify column properties json;")
    ]



#!/usr/bin/env python

from setuptools import find_packages, setup

setup(
    name='django-mfa2',
    version='0.8.7',
    description='Allows user to add 2FA to their accounts',
    author='Mohamed El-Kalioby',
    author_email = 'mkalioby@mkalioby.com',
    url = 'https://github.com/mkalioby/django-mfa2/',

    download_url='https://github.com/mkalioby/django-mfa2/',
    license='MIT',
    packages=find_packages(),
    install_requires=[
        'Django>=1.7',
        'jsonfield',
        'simplejson'
        'pyotp',
        'python-u2flib-server',
        'ua-parser',
        'user-agents',
        'python-jose',
        'fido2==0.5'
      ],
    include_package_data=True,
      zip_safe=False, # because we're including static files
)
